@@ -1,7 +1,7 @@
 def __bootstrap__():
     global __bootstrap__, __loader__, __file__
     import sys, pkg_resources, importlib.util
-    __file__ = pkg_resources.resource_filename(__name__, '_libfdt.cpython-311-x86_64-msys.dll')
+    __file__ = pkg_resources.resource_filename(__name__, '_libfdt.cpython-312-x86_64-cygwin.dll')
     __loader__ = None; del __bootstrap__, __loader__
     spec = importlib.util.spec_from_file_location(__name__,__file__)
     mod = importlib.util.module_from_spec(spec)
